# Cricpy

A GAME

## Env to set before running

```
TOTAL_OVERS=<total overs:int>
FIRST=<first batting cricket team short form:string>
SECOND=<second batting cricket team short form:string>
QUICK_TESTING=<quick testing to kill the sleep time (0/1) :int>
SLEEP_TIME_SECONDS=<sleep time in seconds (usually 1 or 0.5):float>
```